% ------------------------------------------------------------------------------
% Compute DOXY from C1PHASE_DOXY and C2PHASE_DOXY using TEMP_DOXY provided by
% the OPTODE SENSOR.
% The method used is the Aanderaa standard calibration or the Aanderaa
% standard calibration.
%
% SYNTAX :
%  [o_doxyValues] = compute_DOXY_202_207_208( ...
%    a_c1PhaseDoxyValues, a_c2PhaseDoxyValues, a_tempDoxyValues, ...
%    a_presValues, a_psalValues)
%
% INPUT PARAMETERS :
%   a_c1PhaseDoxyValues : input C1PHASE_DOXY data
%   a_c2PhaseDoxyValues : input C2PHASE_DOXY data
%   a_tempDoxyValues    : input TEMP_DOXY data
%   a_presValues        : input PRES data
%   a_psalValues        : input PSAL data
%
% OUTPUT PARAMETERS :
%   o_doxyValues : output DOXY data
%
% EXAMPLES :
%
% SEE ALSO :
% AUTHORS  : Jean-Philippe Rannou (Altran)(jean-philippe.rannou@altran.com)
% ------------------------------------------------------------------------------
% RELEASES :
%   12/03/2014 - RNU - creation
% ------------------------------------------------------------------------------
function [o_doxyValues] = compute_DOXY_202_207_208( ...
   a_c1PhaseDoxyValues, a_c2PhaseDoxyValues, a_tempDoxyValues, ...
   a_presValues, a_psalValues)

% current float WMO number
global g_decPrv_floatNum;

% current cycle number
global g_decPrv_cycleNum;

% default values
global g_decPrv_c1C2PhaseDoxyDef;
global g_decPrv_tempDoxyDef;
global g_decPrv_doxyDef;
global g_decPrv_presDef;
global g_decPrv_salDef;

% arrays to store calibration information
global g_decPrv_calibInfo;

% output parameters initialization
o_doxyValues = ones(length(a_c1PhaseDoxyValues), 1)*g_decPrv_doxyDef;


if (isempty(a_c1PhaseDoxyValues) || isempty(a_c2PhaseDoxyValues) || isempty(a_tempDoxyValues))
   return;
end

% get calibration information
if (isempty(g_decPrv_calibInfo))
   fprintf('WARNING: Float #%d Cycle #%d: DOXY calibration coefficients are missing => DOXY data set to fill value\n', ...
      g_decPrv_floatNum, g_decPrv_cycleNum);
   return;
elseif ((isfield(g_decPrv_calibInfo, 'OPTODE')) && (isfield(g_decPrv_calibInfo.OPTODE, 'TabDoxyCoef')))
   tabDoxyCoef = g_decPrv_calibInfo.OPTODE.TabDoxyCoef;
   % the size of the tabDoxyCoef should be: size(tabDoxyCoef) = 5 28 for the
   % Aanderaa standard calibration
   % the size of the tabDoxyCoef should be: size(tabDoxyCoef) = 6 28 for the
   % Aanderaa standard calibration + an additional two-point adjustment
   % as tempValues come from the TEMP_DOXY, we don't use TempCoefI (see next
   % line)
   tabDoxyCoef(2, 1:6) = [0 1 0 0 0 0];
else
   fprintf('WARNING: Float #%d Cycle #%d: DOXY calibration coefficients are missing => DOXY data set to fill value\n', ...
      g_decPrv_floatNum, g_decPrv_cycleNum);
   return;
end

idDef = find( ...
   (a_c1PhaseDoxyValues == g_decPrv_c1C2PhaseDoxyDef) | ...
   (a_c2PhaseDoxyValues == g_decPrv_c1C2PhaseDoxyDef) | ...
   (a_tempDoxyValues == g_decPrv_tempDoxyDef) | ...
   (a_presValues == g_decPrv_presDef) | ...
   (a_psalValues == g_decPrv_salDef));
idNoDef = setdiff([1:length(o_doxyValues)], idDef);

if (~isempty(idNoDef))
   
   tPhaseDoxyValues = a_c1PhaseDoxyValues(idNoDef) - a_c2PhaseDoxyValues(idNoDef);
   tempDoxyValues = a_tempDoxyValues(idNoDef);
   presValues = a_presValues(idNoDef);
   psalValues = a_psalValues(idNoDef);

   % compute MOLAR_DOXY from TPHASE_DOXY using the Aanderaa standard calibration
   % or the Aanderaa standard calibration + an additional two-point adjustment
   S0 = 0;
   molarDoxyValues = calcoxy_aanderaa4330(tPhaseDoxyValues, tempDoxyValues, ...
      'aanderaa', tabDoxyCoef, S0);
   
   % salinity effect correction
   Sref = 0;
   oxygenSalComp = calcoxy_salcomp(molarDoxyValues, psalValues, tempDoxyValues, Sref);

   % pressure effect correction
   oxygenPresComp = calcoxy_prescomp(oxygenSalComp, presValues);
   
   % compute potential temperature and potential density
   tpot = tetai(presValues, tempDoxyValues, psalValues, 0);
   [~, sigma0] = swstat90(psalValues, tpot, 0);
   rho = (sigma0+1000)/1000;
   
   % units convertion (micromol/L to micromol/kg)
   oxyValues = oxygenPresComp ./ rho;
   
   o_doxyValues(idNoDef) = oxyValues;
end

return;
